# CLIMG Tools
A personal python package for image processing

## Description
The package climg-tools is used for:
* Processing
    * Histogram matching
    * Structural similarity
    * Resize image
* Plot
    * Read image
    * Save image
    * Plot image
    * Plot result
    * Plot histogram

## Installation
Use the package manager [pip](https://pip.pypa.io/en/stable/) to install climg-tools

```bash
pip install climg-tools
```

## Author
Luiz Carlos Dev

## License
[GPL](http://www.gnu.org/licenses/gpl.html)